@@ -20,7 +20,7 @@
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.
+;; along with GNU Emacs.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -154,9 +154,10 @@
      "chromium_pkg_die" "chromium_remove_language_paks"
      "chromium_suid_sandbox_check_kernel_config"
      ;; cmake
-     "cmake_build" "cmake_comment_add_subdirectory" "cmake_run_in"
-     "cmake_src_compile" "cmake_src_configure" "cmake_src_install"
-     "cmake_src_prepare" "cmake_src_test" "cmake_use_find_package"
+     "cmake_build" "cmake_comment_add_subdirectory" "cmake_prepare"
+     "cmake_prepare-per-cmakelists" "cmake_run_in" "cmake_src_compile"
+     "cmake_src_configure" "cmake_src_install" "cmake_src_prepare"
+     "cmake_src_test" "cmake_use_find_package"
      ;; cmake-multilib
      "cmake-multilib_src_compile" "cmake-multilib_src_configure"
      "cmake-multilib_src_install" "cmake-multilib_src_test"
@@ -202,11 +203,13 @@
      "distutils-r1_src_configure" "distutils-r1_src_install"
      "distutils-r1_src_prepare" "distutils-r1_src_test"
      "distutils_enable_sphinx" "distutils_enable_tests"
-     "distutils_install_for_testing" "distutils_pep517_install"
-     "distutils_wheel_install" "distutils_write_namespace" "esetup.py"
+     "distutils_pep517_install" "distutils_wheel_install"
+     "distutils_write_namespace" "esetup.py"
      ;; docs
      "docs_compile" "doxygen_compile" "initialize_git_repo" "mkdocs_compile"
      "sphinx_compile"
+     ;; dot-a
+     "lto-guarantee-fat" "strip-lto-bytecode"
      ;; dotnet
      "dotnet_multilib_comply" "dotnet_pkg_setup" "egacinstall" "exbuild"
      ;; dotnet-pkg
@@ -265,6 +268,9 @@
      "eumask_push" "evar_pop" "evar_push" "evar_push_set"
      ;; fcaps
      "fcaps" "fcaps_pkg_postinst"
+     ;; ffmpeg-compat
+     "ffmpeg_compat_add_flags" "ffmpeg_compat_get_prefix"
+     "ffmpeg_compat_setup"
      ;; findlib
      "check_ocamlfind" "findlib_src_install" "findlib_src_preinst"
      ;; fixheadtails
@@ -277,9 +283,9 @@
      "is-flagq" "is-ldflag" "is-ldflagq" "no-as-needed" "raw-ldflags"
      "replace-cpu-flags" "replace-flags" "replace-sparc64-flags" "strip-flags"
      "strip-unsupported-flags" "test-compile" "test-flag-CC" "test-flag-CCLD"
-     "test-flag-CXX" "test-flag-F77" "test-flag-FC" "test-flags"
-     "test-flags-CC" "test-flags-CCLD" "test-flags-CXX" "test-flags-F77"
-     "test-flags-FC" "test_version_info"
+     "test-flag-CXX" "test-flag-F77" "test-flag-FC" "test-flag-HIPCXX"
+     "test-flags" "test-flags-CC" "test-flags-CCLD" "test-flags-CXX"
+     "test-flags-F77" "test-flags-FC" "test-flags-HIPCXX" "test_version_info"
      ;; font
      "font_cleanup_dirs" "font_fontconfig" "font_pkg_postinst"
      "font_pkg_postrm" "font_pkg_setup" "font_src_install"
@@ -369,17 +375,18 @@
      "guile_export" "guile_filter_pkgconfig_path" "guile_generate_depstrings"
      "guile_set_common_vars" "guile_unstrip_ccache"
      ;; haskell-cabal
-     "cabal-bootstrap" "cabal-build" "cabal-configure" "cabal-constraint"
-     "cabal-copy" "cabal-die-if-nonempty" "cabal-export-dist-libs"
-     "cabal-haddock" "cabal-hscolour" "cabal-is-dummy-lib" "cabal-mksetup"
-     "cabal-pkg" "cabal-register-inplace" "cabal-run-dist-bin"
-     "cabal-show-brokens" "cabal-show-brokens-and-die" "cabal-show-old"
-     "cabal-version" "cabal_chdeps" "cabal_flag" "cabal_src_compile"
-     "cabal_src_configure" "cabal_src_install" "haskell-cabal-run_verbose"
-     "haskell-cabal_pkg_postinst" "haskell-cabal_pkg_postrm"
-     "haskell-cabal_pkg_setup" "haskell-cabal_src_compile"
-     "haskell-cabal_src_configure" "haskell-cabal_src_install"
-     "haskell-cabal_src_prepare" "haskell-cabal_src_test" "replace-hcflags"
+     "cabal-bootstrap" "cabal-build" "cabal-check-cache" "cabal-configure"
+     "cabal-constraint" "cabal-copy" "cabal-die-if-nonempty"
+     "cabal-export-dist-libs" "cabal-haddock" "cabal-hscolour"
+     "cabal-is-dummy-lib" "cabal-mksetup" "cabal-pkg" "cabal-register-inplace"
+     "cabal-run-dist-bin" "cabal-show-brokens" "cabal-show-brokens-and-die"
+     "cabal-show-old" "cabal-version" "cabal_chdeps" "cabal_flag"
+     "cabal_src_compile" "cabal_src_configure" "cabal_src_install"
+     "haskell-cabal-run_verbose" "haskell-cabal_pkg_postinst"
+     "haskell-cabal_pkg_postrm" "haskell-cabal_pkg_setup"
+     "haskell-cabal_src_compile" "haskell-cabal_src_configure"
+     "haskell-cabal_src_install" "haskell-cabal_src_prepare"
+     "haskell-cabal_src_test" "replace-hcflags"
      ;; java-osgi
      "java-osgi_dojar" "java-osgi_dojar-fromfile" "java-osgi_newjar"
      "java-osgi_newjar-fromfile"
@@ -412,6 +419,8 @@
      "java-vm-2_pkg_prerm" "java-vm-2_pkg_setup" "java-vm_install-env"
      "java-vm_revdep-mask" "java-vm_sandbox-predict"
      "java-vm_set-pax-markings"
+     ;; junit5
+     "ejunit5" "junit5_pkg_setup" "junit5_src_test"
      ;; kde.org
      "kde.org_pkg_info" "kde.org_pkg_nofetch" "kde.org_src_unpack"
      ;; kernel-2
@@ -438,8 +447,6 @@
      "kernel-install_pkg_preinst" "kernel-install_pkg_pretend"
      "kernel-install_src_test" "kernel-install_test"
      "kernel-install_update_symlink"
-     ;; kodi-addon
-     "kodi-addon_src_configure"
      ;; latex-package
      "latex-package_pkg_postinst" "latex-package_pkg_postrm"
      "latex-package_rehash" "latex-package_src_compile"
@@ -477,8 +484,8 @@
      "generate_llvm_config" "get_llvm_prefix" "llvm-r2_pkg_setup"
      "llvm_cbuild_setup" "llvm_chost_setup" "llvm_gen_dep"
      ;; llvm-utils
-     "llvm_fix_clang_version" "llvm_fix_tool_path" "llvm_prepend_path"
-     "llvm_tuple_to_target"
+     "llvm_cmake_use_musl" "llvm_fix_clang_version" "llvm_fix_tool_path"
+     "llvm_prepend_path" "llvm_tuple_to_target"
      ;; llvm.org
      "get_lit_flags" "llvm.org_set_globals" "llvm.org_src_prepare"
      "llvm.org_src_unpack" "llvm_are_manpages_built" "llvm_install_manpages"
@@ -548,6 +555,17 @@
      "myspell-r2_src_install" "myspell-r2_src_unpack"
      ;; netsurf
      "netsurf_define_makeconf"
+     ;; nginx
+     "econf_ngx" "nginx_pkg_postinst" "nginx_pkg_setup" "nginx_src_compile"
+     "nginx_src_configure" "nginx_src_install" "nginx_src_prepare"
+     "nginx_src_test" "nginx_src_unpack"
+     ;; nginx-module
+     "econf_ngx" "nginx-module_pkg_postinst" "nginx-module_src_compile"
+     "nginx-module_src_configure" "nginx-module_src_install"
+     "nginx-module_src_prepare" "nginx-module_src_test"
+     "nginx-module_src_unpack" "ngx_mod_append_libs" "ngx_mod_link_lib"
+     "ngx_mod_link_module" "ngx_mod_pkg_to_sonames"
+     "ngx_mod_setup_link_modules"
      ;; ninja-utils
      "eninja" "get_NINJAOPTS"
      ;; nuget
@@ -613,7 +631,8 @@
      ;; preserve-libs
      "preserve_old_lib" "preserve_old_lib_notify"
      ;; pypi
-     "pypi_normalize_name" "pypi_sdist_url" "pypi_translate_version"
+     "pypi_normalize_name" "pypi_provenance_url" "pypi_sdist_url"
+     "pypi_src_unpack" "pypi_translate_version" "pypi_verify_provenance"
      "pypi_wheel_name" "pypi_wheel_url"
      ;; python-any-r1
      "python-any-r1_pkg_setup" "python_gen_any_dep" "python_setup"
@@ -670,7 +689,8 @@
      "rebar3_src_configure" "rebar3_src_install" "rebar3_src_prepare"
      "rebar3_src_test"
      ;; rocm
-     "check_amdgpu" "get_amdgpu_flags" "rocm_use_hipcc"
+     "check_amdgpu" "get_amdgpu_flags" "rocm_add_sandbox" "rocm_use_clang"
+     "rocm_use_hipcc"
      ;; rpm
      "rpm_src_unpack" "rpm_unpack" "srcrpm_unpack"
      ;; ruby-fakegem
@@ -708,6 +728,8 @@
      "restore_config" "save_config" "savedconfig_pkg_postinst"
      ;; scons-utils
      "escons"
+     ;; sec-keys
+     "sec-keys_src_compile" "sec-keys_src_install" "sec-keys_src_test"
      ;; secureboot
      "secureboot_auto_sign" "secureboot_pkg_setup" "secureboot_sign_efi_file"
      ;; selinux-policy-2
@@ -729,6 +751,8 @@
      ;; subversion
      "subversion_fetch" "subversion_pkg_preinst" "subversion_src_unpack"
      "subversion_wc_info"
+     ;; sysroot
+     "qemu_arch" "sysroot_make_run_prefixed" "sysroot_run_prefixed"
      ;; systemd
      "systemd_dounit" "systemd_douserunit" "systemd_enable_ntpunit"
      "systemd_enable_service" "systemd_get_sleepdir"
@@ -757,11 +781,11 @@
      "fix_libtool_libdir_paths" "gcc-abi-map" "gcc-lang-supported"
      "gcc-multilib-configure" "gcc_do_filter_flags" "gcc_do_make"
      "gcc_movelibs" "gentoo_urls" "get_gcc_src_uri" "get_make_var" "is_ada"
-     "is_crosscompile" "is_cxx" "is_d" "is_f77" "is_f95" "is_fortran" "is_go"
-     "is_jit" "is_modula2" "is_multilib" "is_objc" "is_objcxx" "is_rust"
-     "setup_multilib_osdirnames" "should_we_gcc_config"
-     "tc_enable_hardened_gcc" "tc_has_feature" "tc_is_live"
-     "tc_use_major_version_only" "tc_version_is_at_least"
+     "is_algol68" "is_cobol" "is_crosscompile" "is_cxx" "is_d" "is_f77"
+     "is_f95" "is_fortran" "is_go" "is_jit" "is_modula2" "is_multilib"
+     "is_objc" "is_objcxx" "is_rust" "setup_multilib_osdirnames"
+     "should_we_gcc_config" "tc_enable_hardened_gcc" "tc_has_feature"
+     "tc_is_live" "tc_use_major_version_only" "tc_version_is_at_least"
      "tc_version_is_between" "toolchain_death_notice" "toolchain_pkg_postinst"
      "toolchain_pkg_postrm" "toolchain_pkg_preinst" "toolchain_pkg_pretend"
      "toolchain_pkg_setup" "toolchain_src_compile" "toolchain_src_configure"
@@ -776,8 +800,8 @@
      "gcc-major-version" "gcc-micro-version" "gcc-minor-version"
      "gcc-specs-directive" "gcc-specs-nostrict" "gcc-specs-now"
      "gcc-specs-pie" "gcc-specs-relro" "gcc-specs-ssp" "gcc-specs-ssp-to-all"
-     "gcc-specs-stack-check" "gcc-version" "gen_usr_ldscript" "tc-arch"
-     "tc-arch-kernel" "tc-check-min_ver" "tc-check-openmp" "tc-cpp-is-true"
+     "gcc-specs-stack-check" "gcc-version" "tc-arch" "tc-arch-kernel"
+     "tc-check-min_ver" "tc-check-openmp" "tc-cpp-is-true"
      "tc-detect-is-softfloat" "tc-enables-cxx-assertions"
      "tc-enables-fortify-source" "tc-enables-pie" "tc-enables-ssp"
      "tc-enables-ssp-all" "tc-enables-ssp-strong" "tc-endian" "tc-env_build"
@@ -789,10 +813,10 @@
      "tc-getBUILD_PROG" "tc-getBUILD_RANLIB" "tc-getBUILD_READELF"
      "tc-getBUILD_STRINGS" "tc-getBUILD_STRIP" "tc-getCC" "tc-getCPP"
      "tc-getCXX" "tc-getDLLWRAP" "tc-getF77" "tc-getFC" "tc-getGCJ" "tc-getGO"
-     "tc-getLD" "tc-getNM" "tc-getOBJCOPY" "tc-getOBJDUMP" "tc-getPKG_CONFIG"
-     "tc-getPROG" "tc-getRANLIB" "tc-getRC" "tc-getREADELF" "tc-getSTRINGS"
-     "tc-getSTRIP" "tc-getTARGET_CPP" "tc-has-64bit-time_t" "tc-has-tls"
-     "tc-is-clang" "tc-is-cross-compiler" "tc-is-gcc" "tc-is-lto"
+     "tc-getHIPCXX" "tc-getLD" "tc-getNM" "tc-getOBJCOPY" "tc-getOBJDUMP"
+     "tc-getPKG_CONFIG" "tc-getPROG" "tc-getRANLIB" "tc-getRC" "tc-getREADELF"
+     "tc-getSTRINGS" "tc-getSTRIP" "tc-getTARGET_CPP" "tc-has-64bit-time_t"
+     "tc-has-tls" "tc-is-clang" "tc-is-cross-compiler" "tc-is-gcc" "tc-is-lto"
      "tc-is-softfloat" "tc-is-static-only" "tc-ld-disable-gold"
      "tc-ld-force-bfd" "tc-ld-is-bfd" "tc-ld-is-gold" "tc-ld-is-lld"
      "tc-ld-is-mold" "tc-ninja_magic_to_arch" "tc-stack-grows-down"
@@ -852,6 +876,10 @@
      "webapp_postupgrade_txt" "webapp_read_config" "webapp_server_configfile"
      "webapp_serverowned" "webapp_sqlscript" "webapp_src_install"
      "webapp_src_preinst"
+     ;; wine
+     "wine_pkg_postinst" "wine_pkg_postrm" "wine_pkg_pretend"
+     "wine_src_compile" "wine_src_configure" "wine_src_install"
+     "wine_src_prepare"
      ;; wrapper
      "make_wrapper"
      ;; wxwidgets
@@ -870,6 +898,9 @@
      "xorg-3_pkg_postrm" "xorg-3_pkg_setup" "xorg-3_reconf_source"
      "xorg-3_src_compile" "xorg-3_src_configure" "xorg-3_src_install"
      "xorg-3_src_prepare" "xorg-3_src_unpack"
+     ;; xorg-meson
+     "xorg-meson_src_configure" "xorg-meson_src_install"
+     "xorg-meson_src_unpack"
      ;; zig
      "zig_get_jobs" "zig_init_base_args" "zig_live_fetch" "zig_pkg_setup"
      "zig_src_compile" "zig_src_configure" "zig_src_install" "zig_src_prepare"
